==> acf-kamailio-0.5.1.tar.bz2: acf-kamailio-0.5.1/kamailio-controller.lua <==
module(..., package.seeall)

default_action = "status"

function status(self)
	return self.model.getstatus()
end

function startstop(self)
	return self.handle_form(self, self.model.get_startstop, self.model.startstop_service, self.clientdata)
end

function listfiles(self)
	return self.model.list_files()
end

function edit(self)
	return self.handle_form(self, function() return self.model.get_filedetails(self.clientdata.filename) end, self.model.update_filedetails, self.clientdata, "Save", "Edit File", "File Saved")
end

function listusers(self)
	return self.model.list_users()
end

function createuser(self)
	return self.handle_form(self, self.model.get_new_user, self.model.create_new_user, self.clientdata, "Create", "Create New User")
end

function deleteuser(self)
	return self.handle_form(self, self.model.get_delete_user, self.model.delete_user, self.clientdata, "Delete", "Delete User")
	--, "User deleted")
end

function updateuser(self)
	return self.handle_form(self, function() return self.model.get_user(self.clientdata.username) end, self.model.update_user, self.clientdata, "Update", "Update User")
end

function listtables(self)
	return self.model.list_tables()
end

function viewtable(self)
	return self.model.list_table_entries(self.clientdata.table)
end

function deletetableentry(self)
	return self.handle_form(self, self.model.get_delete_table_entry, self.model.delete_table_entry, self.clientdata, "Delete", "Delete Table Entry", "Table Entry deleted")
end

function updatetableentry(self)
	return self.handle_form(self, function() return self.model.get_table_entry(self.clientdata.table, self.clientdata.id) end, self.model.update_table_entry, self.clientdata, "Update", "Update Table Entry", "Entry updated")
end

function createtableentry(self)
	return self.handle_form(self, function() return self.model.get_table_entry(self.clientdata.table) end, self.model.create_table_entry, self.clientdata, "Create", "Create New Table Entry", "Entry created")
end

function createdatabase(self)
	return self.handle_form(self, self.model.get_create_database, self.model.create_database, self.clientdata, "Create", "Create Database", "Database created")
end

searchdatabase = function( self )
	return self.model.search_database(self.clientdata.id, self.clientdata.value, self.clientdata.comparison)
end

==> acf-kamailio-0.6.2.tar.bz2: acf-kamailio-0.6.2/kamailio-controller.lua <==
module(..., package.seeall)

default_action = "status"

function status(self)
	return self.model.getstatus()
end

function startstop(self)
	return self.handle_form(self, self.model.get_startstop, self.model.startstop_service, self.clientdata)
end

function listfiles(self)
	return self.model.list_files()
end

function edit(self)
	return self.handle_form(self, self.model.get_filedetails, self.model.update_filedetails, self.clientdata, "Save", "Edit File", "File Saved")
end

function listusers(self)
	return self.model.list_users()
end

function createuser(self)
	return self.handle_form(self, self.model.get_new_user, self.model.create_new_user, self.clientdata, "Create", "Create New User")
end

function deleteuser(self)
	return self.handle_form(self, self.model.get_delete_user, self.model.delete_user, self.clientdata, "Delete", "Delete User")
	--, "User deleted")
end

function updateuser(self)
	return self.handle_form(self, self.model.get_user, self.model.update_user, self.clientdata, "Update", "Update User")
end

function listtables(self)
	return self.model.list_tables()
end

function viewtable(self)
	return self.model.list_table_entries(self.clientdata.table)
end

function deletetableentry(self)
	return self.handle_form(self, self.model.get_delete_table_entry, self.model.delete_table_entry, self.clientdata, "Delete", "Delete Table Entry", "Table Entry deleted")
end

function updatetableentry(self)
	return self.handle_form(self, self.model.get_table_entry, self.model.update_table_entry, self.clientdata, "Update", "Update Table Entry", "Entry updated")
end

function createtableentry(self)
	return self.handle_form(self, self.model.get_new_table_entry, self.model.create_table_entry, self.clientdata, "Create", "Create New Table Entry", "Entry created")
end

function createdatabase(self)
	return self.handle_form(self, self.model.get_create_database, self.model.create_database, self.clientdata, "Create", "Create Database", "Database created")
end

searchdatabase = function( self )
	return self.model.search_database(self.clientdata.id, self.clientdata.value, self.clientdata.comparison)
end
